@@ -317,8 +317,8 @@ categorize.grouped_df <- function(x,
                                   ...) {
   info <- attributes(x)
 
-  # dplyr >= 0.8.0 returns attribute "indices"
-  grps <- attr(x, "groups", exact = TRUE)
+  # works only for dplyr >= 0.8.0
+  grps <- attr(x, "groups", exact = TRUE)[[".rows"]]
 
   # evaluate arguments
   select <- .select_nse(select,
@@ -336,14 +336,6 @@ categorize.grouped_df <- function(x,
   x <- args$x
   select <- args$select
 
-  # dplyr < 0.8.0?
-  if (is.null(grps)) {
-    grps <- attr(x, "indices", exact = TRUE)
-    grps <- lapply(grps, function(x) x + 1)
-  } else {
-    grps <- grps[[".rows"]]
-  }
-
   x <- as.data.frame(x)
   for (rows in grps) {
     x[rows, ] <- categorize(
