@@ -162,9 +162,10 @@ data_tabulate.grouped_df <- function(x,
                                      collapse = FALSE,
                                      drop_levels = FALSE,
                                      ...) {
-  # dplyr < 0.8.0 returns attribute "indices"
+  # works only for dplyr >= 0.8.0
   grps <- attr(x, "groups", exact = TRUE)
-  group_variables <- NULL
+  group_variables <- data_remove(grps, ".rows")
+  grps <- grps[[".rows"]]
 
   # evaluate arguments
   select <- .select_nse(select,
@@ -175,15 +176,6 @@ data_tabulate.grouped_df <- function(x,
     verbose = verbose
   )
 
-  # dplyr < 0.8.0?
-  if (is.null(grps)) {
-    grps <- attr(x, "indices", exact = TRUE)
-    grps <- lapply(grps, function(x) x + 1)
-  } else {
-    group_variables <- data_remove(grps, ".rows")
-    grps <- grps[[".rows"]]
-  }
-
   x <- as.data.frame(x)
   out <- list()
   for (i in seq_along(grps)) {
