@@ -381,8 +381,8 @@
   }
 
   info <- attributes(x)
-  # dplyr >= 0.8.0 returns attribute "indices"
-  grps <- attr(x, "groups", exact = TRUE)
+  # works only for dplyr >= 0.8.0
+  grps <- attr(x, "groups", exact = TRUE)[[".rows"]]
 
   if (is.numeric(weights)) {
     insight::format_warning(
@@ -392,15 +392,6 @@
     weights <- NULL
   }
 
-
-  # dplyr < 0.8.0?
-  if (is.null(grps)) {
-    grps <- attr(x, "indices", exact = TRUE)
-    grps <- lapply(grps, function(x) x + 1)
-  } else {
-    grps <- grps[[".rows"]]
-  }
-
   x <- as.data.frame(x)
   select <- .select_variables(x, select, exclude, force)
 
